import * as React from 'react';
import { ButtonVariant_$type } from "./ButtonVariant";
import { IgrButtonBase } from "./igr-button-base";
import { Button } from "./Button";
import { IgcButtonComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum } from "igniteui-react-core";
/**
 * Represents a clickable button, used to submit forms or anywhere in a
 * document for accessible, standard button functionality.
*/
export class IgrButton extends IgrButtonBase {
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcButtonComponent);
    }
    createImplementation() {
        return new Button();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        let div = React.createElement("igc-button", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * Sets the variant of the button.
    */
    get variant() {
        return this.i.u;
    }
    set variant(v) {
        this.i.u = ensureEnum(ButtonVariant_$type, v);
    }
}
