import * as React from 'react';
import { IgrSplitPaneCollection } from "./igr-split-pane-collection";
import { DockManagerLayout } from "./DockManagerLayout";
import { TypeRegistrar } from "igniteui-react-core";
import { NamePatcher, getModifiedProps, isValidProp, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
import { SplitPaneCollection as SplitPaneCollection_internal } from "./SplitPaneCollection";
import { SplitPane } from "./SplitPane";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
/**
 * Describes a Dock Manager layout.
*/
export class IgrDockManagerLayout extends React.Component {
    constructor(props) {
        super(props);
        this._floatingPanes = null;
        this.__p = null;
        this._hasUserValues = new Set();
        this._stylingContainer = null;
        this._stylingParent = null;
        this._inStyling = false;
        if (this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
        }
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new DockManagerLayout();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    } /**
                                 * @hidden
                                 */
    static _createFromInternal(internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        let name = internal.$type.name;
        let externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    }
    onImplementationCreated() {
    }
    componentDidMount() {
        for (const p of Object.keys(this.props)) {
            if (isValidProp(this, p)) {
                this[p] = this.props[p];
            }
        }
    }
    shouldComponentUpdate(nextProps, nextState) {
        const mod = getModifiedProps(this.props, nextProps);
        for (const p of Object.keys(mod)) {
            if (isValidProp(this, p)) {
                this[p] = mod[p];
            }
        }
        return true;
    }
    render() {
        return null;
    }
    /**
     * The root split pane of the layout.
    */
    get rootPane() {
        if (this.i.a == null) {
            return null;
        }
        return this.i.a.externalObject;
    }
    set rootPane(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.a = null : this.i.a = v.i;
    }
    /**
     * The floating panes of the layout.
    */
    get floatingPanes() {
        if (this._floatingPanes === null) {
            let coll = new IgrSplitPaneCollection();
            let innerColl = this.i.b;
            if (!innerColl) {
                innerColl = new SplitPaneCollection_internal();
            }
            this._floatingPanes = coll._fromInner(innerColl);
            this.i.b = innerColl;
        }
        return this._floatingPanes;
    }
    set floatingPanes(v) {
        if (this._floatingPanes !== null) {
            this._floatingPanes._setSyncTarget(null);
            this._floatingPanes = null;
        }
        let coll = new IgrSplitPaneCollection();
        this._floatingPanes = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(SplitPane.$type);
        let innerColl = this.i.b;
        if (!innerColl) {
            innerColl = new SplitPaneCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._floatingPanes._setSyncTarget(syncColl);
        this.i.b = innerColl;
    }
    findByName(name) {
        if (this.rootPane && this.rootPane.name && this.rootPane.name == name) {
            return this.rootPane;
        }
        if (this.floatingPanes != null && this.floatingPanes.findByName && this.floatingPanes.findByName(name)) {
            return this.floatingPanes.findByName(name);
        }
        return null;
    }
    get hasUserValues() {
        return this._hasUserValues;
    }
    __m(propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    }
    _styling(container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        let genericPrefix = "";
        let typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("DockManagerLayout");
        let additionalPrefixes = [];
        let prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        let b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            let basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            let parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            let parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this.rootPane && this.rootPane._styling) {
            this.rootPane._styling(container, component, this);
        }
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    }
}
