import * as React from 'react';
import { MaskInputDir_$type } from "./MaskInputDir";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrInputBase } from "./igr-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
export class IgrMaskInput extends IgrInputBase {
    constructor(props) {
        super(props);
        this._getMainRef = this._getMainRef.bind(this);
        defineComponents(IgcMaskInputComponent);
    }
    createImplementation() {
        return new MaskInput();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    componentDidMount() {
        this.i.nativeElement = this._elRef;
        super.componentDidMount();
    }
    render() {
        let propChildren = this.props.children;
        let children = [];
        React.Children.forEach(propChildren, (ch) => {
            children.push(React.cloneElement(ch));
        });
        let div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    }
    _getMainRef(ref) {
        this._elRef = ref;
    }
    /**
     * The direction attribute of the control.
    */
    get dir() {
        return this.i.y;
    }
    set dir(v) {
        this.i.y = ensureEnum(MaskInputDir_$type, v);
    }
    /**
     * Controls the validity of the control.
    */
    get invalid() {
        return this.i.aa;
    }
    set invalid(v) {
        this.i.aa = ensureBool(v);
    }
    /**
     * Dictates the behavior when retrieving the value of the control:
     * - `raw` will return the clean user input.
     * - `withFormatting` will return the value with all literals and prompts.
    */
    get valueMode() {
        return this.i.z;
    }
    set valueMode(v) {
        this.i.z = ensureEnum(MaskInputValueMode_$type, v);
    }
    get value() {
        return this.i.ad;
    }
    set value(v) {
        this.i.ad = v;
    }
    /**
     * The mask pattern to apply on the input.
    */
    get mask() {
        return this.i.ab;
    }
    set mask(v) {
        this.i.ab = v;
    }
    /**
     * The prompt symbol to use for unfilled parts of the mask.
    */
    get prompt() {
        return this.i.ac;
    }
    set prompt(v) {
        this.i.ac = v;
    }
    connectedCallback() {
        this.i.af();
    }
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    reportValidity() {
        this.i.ag();
    }
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    setCustomValidity(message) {
        this.i.ai(message);
    }
    /**
     * Check for validity of the control
    
    */
    checkValidity() {
        this.i.ae();
    }
    /**
     * Selects all text within the input.
    
    */
    select() {
        this.i.ah();
    }
}
