import { DockManagerPaneType_$type } from "./DockManagerPaneType";
import { SplitPaneOrientation_$type } from "./SplitPaneOrientation";
import { IgrDockManagerPaneCollection } from "./igr-dock-manager-pane-collection";
import { IgrDockManagerPane } from "./igr-dock-manager-pane";
import { SplitPane } from "./SplitPane";
import { ensureEnum, ensureBool } from "igniteui-react-core";
import { DockManagerPaneCollection as DockManagerPaneCollection_internal } from "./DockManagerPaneCollection";
import { DockManagerPane } from "./DockManagerPane";
import { SyncableObservableCollection$1 } from "igniteui-react-core";
export class IgrSplitPane extends IgrDockManagerPane {
    constructor(props) {
        super(props);
        this._panes = null;
    }
    createImplementation() {
        return new SplitPane();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    /**
     * The id of the pane. If not set the Dock Manager generates it automatically.
    */
    get id() {
        return this.i.r;
    }
    set id(v) {
        this.i.r = v;
    }
    /**
     * The type of the pane.
    */
    get paneType() {
        return this.i.f;
    }
    set paneType(v) {
        this.i.f = ensureEnum(DockManagerPaneType_$type, v);
    }
    /**
     * The orientation of the split pane.
    */
    get orientation() {
        return this.i.h;
    }
    set orientation(v) {
        this.i.h = ensureEnum(SplitPaneOrientation_$type, v);
    }
    /**
     * The child panes of the split pane.
    */
    get panes() {
        if (this._panes === null) {
            let coll = new IgrDockManagerPaneCollection();
            let innerColl = this.i.e;
            if (!innerColl) {
                innerColl = new DockManagerPaneCollection_internal();
            }
            this._panes = coll._fromInner(innerColl);
            this.i.e = innerColl;
        }
        return this._panes;
    }
    set panes(v) {
        if (this._panes !== null) {
            this._panes._setSyncTarget(null);
            this._panes = null;
        }
        let coll = new IgrDockManagerPaneCollection();
        this._panes = coll._fromOuter(v);
        let syncColl = new SyncableObservableCollection$1(DockManagerPane.$type);
        let innerColl = this.i.e;
        if (!innerColl) {
            innerColl = new DockManagerPaneCollection_internal();
        }
        syncColl._inner = innerColl;
        syncColl.clear();
        this._panes._setSyncTarget(syncColl);
        this.i.e = innerColl;
    }
    /**
     * The size of the pane relative to its sibling panes' sizes. Defaults to 100.
    */
    get size() {
        return this.i.o;
    }
    set size(v) {
        this.i.o = +v;
    }
    /**
     * The absolute location point of the pane. Applies only for floating panes.
    */
    get floatingLocation() {
        if (this.i.g == null) {
            return null;
        }
        return this.i.g.externalObject;
    }
    set floatingLocation(v) {
        if (v != null && this._stylingContainer && v._styling)
            v._styling(this._stylingContainer, this, this);
        v == null ? this.i.g = null : this.i.g = v.i;
    }
    /**
     * The absolute width of the pane. Applies only for floating panes. Defaults to 100.
    */
    get floatingWidth() {
        return this.i.n;
    }
    set floatingWidth(v) {
        this.i.n = +v;
    }
    /**
     * The absolute height of the pane. Applies only for floating panes. Defaults to 100.
    */
    get floatingHeight() {
        return this.i.m;
    }
    set floatingHeight(v) {
        this.i.m = +v;
    }
    /**
     * Determines whether floating pane resizing is allowed. Applies only for floating panes.
    */
    get floatingResizable() {
        return this.i.l;
    }
    set floatingResizable(v) {
        this.i.l = ensureBool(v);
    }
    /**
     * Determines whether the pane should present in the UI when empty.
    */
    get allowEmpty() {
        return this.i.k;
    }
    set allowEmpty(v) {
        this.i.k = ensureBool(v);
    }
    findByName(name) {
        var baseResult = super.findByName(name);
        if (baseResult) {
            return baseResult;
        }
        if (this.panes != null && this.panes.findByName && this.panes.findByName(name)) {
            return this.panes.findByName(name);
        }
        if (this.floatingLocation && this.floatingLocation.name && this.floatingLocation.name == name) {
            return this.floatingLocation;
        }
        return null;
    }
    _styling(container, component, parent) {
        super._styling(container, component, parent);
        this._inStyling = true;
        if (this.floatingLocation && this.floatingLocation._styling) {
            this.floatingLocation._styling(container, component, this);
        }
        this._inStyling = false;
    }
}
