import { __extends, __values } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { ChipVariant_$type } from "./ChipVariant";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { IgrComponentBoolValueChangedEventArgs } from "./igr-component-bool-value-changed-event-args";
import { Chip } from "./Chip";
import { TypeRegistrar } from "igniteui-react-core";
import { IgcChipComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * Chips help people enter information, make selections, filter content, or trigger actions.
*/
var IgrChip = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrChip, _super);
    function IgrChip(props) {
        var _this = _super.call(this, props) || this;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        _this._remove = null;
        _this._remove_wrapped = null;
        _this._select = null;
        _this._select_wrapped = null;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcChipComponent);
        _this._implementation = _this.createImplementation();
        _this._implementation.externalObject = _this;
        _this.onImplementationCreated();
        return _this;
    }
    IgrChip.prototype.createImplementation = function () {
        return new Chip();
    };
    Object.defineProperty(IgrChip.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgrChip._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgrChip.prototype.onImplementationCreated = function () {
    };
    IgrChip.prototype.componentDidMount = function () {
        var e_1, _a;
        this.i.nativeElement = this._elRef;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    IgrChip.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_2, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        return true;
    };
    IgrChip.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-chip", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrChip.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrChip.prototype, "disabled", {
        /**
         * Sets the disabled state for the chip.
        */
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrChip.prototype, "removable", {
        /**
         * Defines if the chip is removable or not.
        */
        get: function () {
            return this.i.h;
        },
        set: function (v) {
            this.i.h = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrChip.prototype, "selectable", {
        /**
         * Defines if the chip is selectable or not.
        */
        get: function () {
            return this.i.i;
        },
        set: function (v) {
            this.i.i = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrChip.prototype, "selected", {
        /**
         * Defines if the chip is selected or not.
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrChip.prototype, "variant", {
        /**
         * A property that sets the color variant of the chip component.
        */
        get: function () {
            return this.i.a;
        },
        set: function (v) {
            this.i.a = ensureEnum(ChipVariant_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrChip.prototype, "size", {
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = ensureEnum(SizableComponentSize_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrChip.prototype.findByName = function (name) {
        return null;
    };
    Object.defineProperty(IgrChip.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrChip.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrChip.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Chip");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    Object.defineProperty(IgrChip.prototype, "remove", {
        get: function () {
            return this._remove;
        },
        set: function (ev) {
            var _this = this;
            if (this._remove_wrapped !== null) {
                this.i.remove = delegateRemove(this.i.remove, this._remove_wrapped);
                this._remove_wrapped = null;
                this._remove = null;
            }
            this._remove = ev;
            this._remove_wrapped = function (o, e) {
                var outerArgs = new IgrComponentBoolValueChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeRemove) {
                    _this.beforeRemove(_this, outerArgs);
                }
                if (_this._remove) {
                    _this._remove(_this, outerArgs);
                }
            };
            this.i.remove = delegateCombine(this.i.remove, this._remove_wrapped);
            if (this.i.removeChanged) {
                this.i.removeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrChip.prototype, "select", {
        get: function () {
            return this._select;
        },
        set: function (ev) {
            var _this = this;
            if (this._select_wrapped !== null) {
                this.i.select = delegateRemove(this.i.select, this._select_wrapped);
                this._select_wrapped = null;
                this._select = null;
            }
            this._select = ev;
            this._select_wrapped = function (o, e) {
                var outerArgs = new IgrComponentBoolValueChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeSelect) {
                    _this.beforeSelect(_this, outerArgs);
                }
                if (_this._select) {
                    _this._select(_this, outerArgs);
                }
            };
            this.i.select = delegateCombine(this.i.select, this._select_wrapped);
            if (this.i.selectChanged) {
                this.i.selectChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrChip;
}(React.Component));
export { IgrChip };
