import { __extends, __values } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { DropdownPlacement_$type } from "./DropdownPlacement";
import { DropdownPositionStrategy_$type } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy_$type } from "./DropdownScrollStrategy";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { IgrDropdownItemComponentEventArgs } from "./igr-dropdown-item-component-event-args";
import { Dropdown } from "./Dropdown";
import { TypeRegistrar } from "igniteui-react-core";
import { IgcDropdownComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, ensureEnum, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * Represents a DropDown component.
*/
var IgrDropdown = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrDropdown, _super);
    function IgrDropdown(props) {
        var _this = _super.call(this, props) || this;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        _this._change = null;
        _this._change_wrapped = null;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcDropdownComponent);
        _this._implementation = _this.createImplementation();
        _this._implementation.externalObject = _this;
        _this.onImplementationCreated();
        return _this;
    }
    IgrDropdown.prototype.createImplementation = function () {
        return new Dropdown();
    };
    Object.defineProperty(IgrDropdown.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgrDropdown._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgrDropdown.prototype.onImplementationCreated = function () {
    };
    IgrDropdown.prototype.componentDidMount = function () {
        var e_1, _a;
        this.i.nativeElement = this._elRef;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    IgrDropdown.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_2, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        return true;
    };
    IgrDropdown.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-dropdown", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrDropdown.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrDropdown.prototype, "keepOpenOnSelect", {
        /**
         * Whether the dropdown should be kept open on selection.
        */
        get: function () {
            return this.i.l;
        },
        set: function (v) {
            this.i.l = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "open", {
        /**
         * Sets the open state of the component.
        */
        get: function () {
            return this.i.m;
        },
        set: function (v) {
            this.i.m = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "placement", {
        /**
         * The preferred placement of the component around the target element.
         * @type {"top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "right" | "right-start" | "right-end" | "left" | "left-start" | "left-end"}
        */
        get: function () {
            return this.i.d;
        },
        set: function (v) {
            this.i.d = ensureEnum(DropdownPlacement_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "positionStrategy", {
        /**
         * Sets the component's positioning strategy.
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = ensureEnum(DropdownPositionStrategy_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "scrollStrategy", {
        /**
         * Determines the behavior of the component during scrolling the container.
        */
        get: function () {
            return this.i.f;
        },
        set: function (v) {
            this.i.f = ensureEnum(DropdownScrollStrategy_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "flip", {
        /**
         * Whether the component should be flipped to the opposite side of the target once it's about to overflow the visible area.
         * When true, once enough space is detected on its preferred side, it will flip back.
        */
        get: function () {
            return this.i.j;
        },
        set: function (v) {
            this.i.j = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "distance", {
        /**
         * The distance from the target element.
        */
        get: function () {
            return this.i.o;
        },
        set: function (v) {
            this.i.o = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "keepOpenOnOutsideClick", {
        /**
         * Whether the component should be kept open on clicking outside of it.
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "sameWidth", {
        /**
         * Whether the dropdown's width should be the same as the target's one.
        */
        get: function () {
            return this.i.n;
        },
        set: function (v) {
            this.i.n = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrDropdown.prototype, "size", {
        get: function () {
            return this.i.g;
        },
        set: function (v) {
            this.i.g = ensureEnum(SizableComponentSize_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdown.prototype.findByName = function (name) {
        return null;
    };
    Object.defineProperty(IgrDropdown.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrDropdown.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrDropdown.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Dropdown");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    /**
     * Shows the dropdown.
    
    */
    IgrDropdown.prototype.show = function () {
        this.i.v();
    };
    /**
     * Toggles the open state of the dropdown.
    
    */
    IgrDropdown.prototype.toggle = function () {
        this.i.x();
    };
    /**
     * Shows the dropdown.
    
    */
    IgrDropdown.prototype.showTarget = function (target_) {
        this.i.showTarget(target_);
    };
    /**
     * Toggles the open state of the dropdown.
    
    */
    IgrDropdown.prototype.toggleTarget = function (target_) {
        this.i.toggleTarget(target_);
    };
    /**
     * Navigates to the item at the specified index. If it exists, returns the found item, otherwise - null.
    
    */
    IgrDropdown.prototype.navigateTo = function (index) {
        var iv = this.i.a(index);
        return (iv == null ? null : iv.externalObject);
    };
    /**
     * Selects the item with the specified value. If it exists, returns the found item, otherwise - null.
    
    */
    IgrDropdown.prototype.select = function (value) {
        var iv = this.i.b(value);
        return (iv == null ? null : iv.externalObject);
    };
    IgrDropdown.prototype.firstUpdated = function () {
        this.i.t();
    };
    /**
     * Hides the dropdown.
    
    */
    IgrDropdown.prototype.hide = function () {
        this.i.u();
    };
    /**
     * Clears the current selection of the dropdown.
    
    */
    IgrDropdown.prototype.clearSelection = function () {
        this.i.s();
    };
    Object.defineProperty(IgrDropdown.prototype, "change", {
        get: function () {
            return this._change;
        },
        set: function (ev) {
            var _this = this;
            if (this._change_wrapped !== null) {
                this.i.change = delegateRemove(this.i.change, this._change_wrapped);
                this._change_wrapped = null;
                this._change = null;
            }
            this._change = ev;
            this._change_wrapped = function (o, e) {
                var outerArgs = new IgrDropdownItemComponentEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeChange) {
                    _this.beforeChange(_this, outerArgs);
                }
                if (_this._change) {
                    _this._change(_this, outerArgs);
                }
            };
            this.i.change = delegateCombine(this.i.change, this._change_wrapped);
            if (this.i.changeChanged) {
                this.i.changeChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrDropdown;
}(React.Component));
export { IgrDropdown };
