import { __extends, __values } from "tslib";
import * as React from 'react';
import { delegateCombine, delegateRemove } from "igniteui-react-core";
import { IgrFormDataEventArgs } from "./igr-form-data-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { Form } from "./Form";
import { TypeRegistrar } from "igniteui-react-core";
import { IgcFormComponent, defineComponents } from "igniteui-webcomponents";
import { NamePatcher, getModifiedProps, isValidProp, ensureBool, toSpinal, initializePropertiesFromCss } from "igniteui-react-core";
/**
 * The form is a component used to collect user input from
 * interactive controls.
*/
var IgrForm = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrForm, _super);
    function IgrForm(props) {
        var _this = _super.call(this, props) || this;
        _this.__p = null;
        _this._hasUserValues = new Set();
        _this._stylingContainer = null;
        _this._stylingParent = null;
        _this._inStyling = false;
        _this._submit = null;
        _this._submit_wrapped = null;
        _this._reset = null;
        _this._reset_wrapped = null;
        if (_this._styling) {
            NamePatcher.ensureStylablePatched(Object.getPrototypeOf(_this));
        }
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcFormComponent);
        _this._implementation = _this.createImplementation();
        _this._implementation.externalObject = _this;
        _this.onImplementationCreated();
        return _this;
    }
    IgrForm.prototype.createImplementation = function () {
        return new Form();
    };
    Object.defineProperty(IgrForm.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        } /**
                                     * @hidden
                                     */,
        enumerable: false,
        configurable: true
    });
    IgrForm._createFromInternal = function (internal) {
        if (!internal) {
            return null;
        }
        if (!internal.$type) {
            return null;
        }
        var name = internal.$type.name;
        var externalName = "Igr" + name;
        if (!TypeRegistrar.isRegistered(externalName)) {
            return null;
        }
        return TypeRegistrar.create(externalName);
    };
    IgrForm.prototype.onImplementationCreated = function () {
    };
    IgrForm.prototype.componentDidMount = function () {
        var e_1, _a;
        this.i.nativeElement = this._elRef;
        try {
            for (var _b = __values(Object.keys(this.props)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = this.props[p];
                }
            }
        }
        catch (e_1_1) {
            e_1 = { error: e_1_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_1)
                    throw e_1.error;
            }
        }
    };
    IgrForm.prototype.shouldComponentUpdate = function (nextProps, nextState) {
        var e_2, _a;
        var mod = getModifiedProps(this.props, nextProps);
        try {
            for (var _b = __values(Object.keys(mod)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var p = _c.value;
                if (isValidProp(this, p)) {
                    this[p] = mod[p];
                }
            }
        }
        catch (e_2_1) {
            e_2 = { error: e_2_1 };
        }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return))
                    _a.call(_b);
            }
            finally {
                if (e_2)
                    throw e_2.error;
            }
        }
        return true;
    };
    IgrForm.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-form", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrForm.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrForm.prototype, "novalidate", {
        /**
         * Specifies if form data validation should be skipped on submit.
        */
        get: function () {
            return this.i.e;
        },
        set: function (v) {
            this.i.e = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrForm.prototype.findByName = function (name) {
        return null;
    };
    Object.defineProperty(IgrForm.prototype, "hasUserValues", {
        get: function () {
            return this._hasUserValues;
        },
        enumerable: false,
        configurable: true
    });
    IgrForm.prototype.__m = function (propertyName) {
        if (!this._inStyling) {
            this._hasUserValues.add(propertyName);
        }
    };
    IgrForm.prototype._styling = function (container, component, parent) {
        if (this._inStyling) {
            return;
        }
        this._inStyling = true;
        this._stylingContainer = container;
        this._stylingParent = component;
        var genericPrefix = "";
        var typeName = this.i.$type.name;
        if (typeName.indexOf("Xam") === 0) {
            typeName = typeName.substring(3);
        }
        genericPrefix = toSpinal("Form");
        var additionalPrefixes = [];
        var prefix = toSpinal(typeName);
        additionalPrefixes.push(prefix + "-");
        var b = this.i.$type.baseType;
        while (b && b.name != "Object" &&
            b.name != "Base" &&
            b.name != "Control" &&
            b.Name != "DependencyObject" &&
            b.Name != "FrameworkElement") {
            typeName = b.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            var basePrefix = toSpinal(typeName);
            additionalPrefixes.push(basePrefix + "-");
            b = b.baseType;
        }
        if (parent) {
            var parentTypeName = parent.i.$type.name;
            if (parentTypeName.indexOf("Xam") === 0) {
                parentTypeName = parentTypeName.substring(3);
            }
            var parentPrefix = toSpinal(parentTypeName);
            additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
            additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
        }
        initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
        if (this._otherStyling) {
            this._otherStyling(container, component, parent);
        }
        this._inStyling = false;
    };
    /**
     * Submits the form.
    
    */
    IgrForm.prototype.performSubmit = function () {
        var iv = this.i.f();
        return (iv);
    };
    /**
     * Resets the form.
    
    */
    IgrForm.prototype.performReset = function () {
        this.i.j();
    };
    /**
     * Checks for validity of the form.
    
    */
    IgrForm.prototype.reportValidity = function () {
        var iv = this.i.g();
        return (iv);
    };
    Object.defineProperty(IgrForm.prototype, "submit", {
        get: function () {
            return this._submit;
        },
        set: function (ev) {
            var _this = this;
            if (this._submit_wrapped !== null) {
                this.i.submit = delegateRemove(this.i.submit, this._submit_wrapped);
                this._submit_wrapped = null;
                this._submit = null;
            }
            this._submit = ev;
            this._submit_wrapped = function (o, e) {
                var outerArgs = new IgrFormDataEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeSubmit) {
                    _this.beforeSubmit(_this, outerArgs);
                }
                if (_this._submit) {
                    _this._submit(_this, outerArgs);
                }
            };
            this.i.submit = delegateCombine(this.i.submit, this._submit_wrapped);
            if (this.i.submitChanged) {
                this.i.submitChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrForm.prototype, "reset", {
        get: function () {
            return this._reset;
        },
        set: function (ev) {
            var _this = this;
            if (this._reset_wrapped !== null) {
                this.i.reset = delegateRemove(this.i.reset, this._reset_wrapped);
                this._reset_wrapped = null;
                this._reset = null;
            }
            this._reset = ev;
            this._reset_wrapped = function (o, e) {
                var outerArgs = new IgrVoidEventArgs();
                outerArgs._provideImplementation(e);
                if (_this.beforeReset) {
                    _this.beforeReset(_this, outerArgs);
                }
                if (_this._reset) {
                    _this._reset(_this, outerArgs);
                }
            };
            this.i.reset = delegateCombine(this.i.reset, this._reset_wrapped);
            if (this.i.resetChanged) {
                this.i.resetChanged();
            }
            ;
        },
        enumerable: false,
        configurable: true
    });
    return IgrForm;
}(React.Component));
export { IgrForm };
