import { __extends } from "tslib";
import * as React from 'react';
import { MaskInputDir_$type } from "./MaskInputDir";
import { MaskInputValueMode_$type } from "./MaskInputValueMode";
import { IgrInputBase } from "./igr-input-base";
import { MaskInput } from "./MaskInput";
import { IgcMaskInputComponent, defineComponents } from "igniteui-webcomponents";
import { ensureEnum, ensureBool } from "igniteui-react-core";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
var IgrMaskInput = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrMaskInput, _super);
    function IgrMaskInput(props) {
        var _this = _super.call(this, props) || this;
        _this._getMainRef = _this._getMainRef.bind(_this);
        defineComponents(IgcMaskInputComponent);
        return _this;
    }
    IgrMaskInput.prototype.createImplementation = function () {
        return new MaskInput();
    };
    Object.defineProperty(IgrMaskInput.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrMaskInput.prototype.componentDidMount = function () {
        this.i.nativeElement = this._elRef;
        _super.prototype.componentDidMount.call(this);
    };
    IgrMaskInput.prototype.render = function () {
        var propChildren = this.props.children;
        var children = [];
        React.Children.forEach(propChildren, function (ch) {
            children.push(React.cloneElement(ch));
        });
        var div = React.createElement("igc-mask-input", {
            ref: this._getMainRef,
            className: this.props.className,
            style: this.props.style,
            children: children
        });
        return div;
    };
    IgrMaskInput.prototype._getMainRef = function (ref) {
        this._elRef = ref;
    };
    Object.defineProperty(IgrMaskInput.prototype, "dir", {
        /**
         * The direction attribute of the control.
        */
        get: function () {
            return this.i.y;
        },
        set: function (v) {
            this.i.y = ensureEnum(MaskInputDir_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "invalid", {
        /**
         * Controls the validity of the control.
        */
        get: function () {
            return this.i.aa;
        },
        set: function (v) {
            this.i.aa = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "valueMode", {
        /**
         * Dictates the behavior when retrieving the value of the control:
         * - `raw` will return the clean user input.
         * - `withFormatting` will return the value with all literals and prompts.
        */
        get: function () {
            return this.i.z;
        },
        set: function (v) {
            this.i.z = ensureEnum(MaskInputValueMode_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "value", {
        get: function () {
            return this.i.ad;
        },
        set: function (v) {
            this.i.ad = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "mask", {
        /**
         * The mask pattern to apply on the input.
        */
        get: function () {
            return this.i.ab;
        },
        set: function (v) {
            this.i.ab = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrMaskInput.prototype, "prompt", {
        /**
         * The prompt symbol to use for unfilled parts of the mask.
        */
        get: function () {
            return this.i.ac;
        },
        set: function (v) {
            this.i.ac = v;
        },
        enumerable: false,
        configurable: true
    });
    IgrMaskInput.prototype.connectedCallback = function () {
        this.i.af();
    };
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    IgrMaskInput.prototype.reportValidity = function () {
        this.i.ag();
    };
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    IgrMaskInput.prototype.setCustomValidity = function (message) {
        this.i.ai(message);
    };
    /**
     * Check for validity of the control
    
    */
    IgrMaskInput.prototype.checkValidity = function () {
        this.i.ae();
    };
    /**
     * Selects all text within the input.
    
    */
    IgrMaskInput.prototype.select = function () {
        this.i.ah();
    };
    return IgrMaskInput;
}(IgrInputBase));
export { IgrMaskInput };
