import * as React from 'react';
import { CalendarHeaderOrientation } from "./CalendarHeaderOrientation";
import { CalendarOrientation } from "./CalendarOrientation";
import { CalendarActiveView } from "./CalendarActiveView";
import { IgrCalendarFormatOptions } from "./igr-calendar-format-options";
import { IgrCalendarResourceStrings } from "./igr-calendar-resource-strings";
import { SizableComponentSize } from "./SizableComponentSize";
import { IgrComponentDataValueChangedEventArgs } from "./igr-component-data-value-changed-event-args";
import { IgrCalendarBase, IIgrCalendarBaseProps } from "./igr-calendar-base";
import { Calendar } from "./Calendar";
/**
 * Represents a calendar that lets users
 * to select a date value in a variety of different ways.
 * when calendar orientation is vertical.
*/
export declare class IgrCalendar extends IgrCalendarBase<IIgrCalendarProps> {
    protected createImplementation(): Calendar;
    /**
                                 * @hidden
                                 */
    get i(): Calendar;
    constructor(props: IIgrCalendarProps);
    componentDidMount(): void;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: string;
        style: React.CSSProperties;
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    get value(): Date;
    set value(v: Date);
    get values(): Date[];
    set values(v: Date[]);
    /**
     * Sets the date which is shown in view and is highlighted. By default it is the current date.
    */
    get activeDate(): Date;
    set activeDate(v: Date);
    /**
     * Controls the visibility of the dates that do not belong to the current month.
    */
    get hideOutsideDays(): boolean;
    set hideOutsideDays(v: boolean);
    /**
     * Determines whether the calendar hides its header. Even if set to false, the header is not displayed for `multiple` selection.
    */
    get hideHeader(): boolean;
    set hideHeader(v: boolean);
    /**
     * The orientation of the header.
    */
    get headerOrientation(): CalendarHeaderOrientation;
    set headerOrientation(v: CalendarHeaderOrientation);
    /**
     * The orientation of the multiple months displayed in days view.
    */
    get orientation(): CalendarOrientation;
    set orientation(v: CalendarOrientation);
    /**
     * The number of months displayed in days view.
    */
    get visibleMonths(): number;
    set visibleMonths(v: number);
    /**
     * The active view.
    */
    get activeView(): CalendarActiveView;
    set activeView(v: CalendarActiveView);
    /**
     * The options used to format the months and the weekdays in the calendar views.
    */
    get formatOptions(): IgrCalendarFormatOptions;
    set formatOptions(v: IgrCalendarFormatOptions);
    /**
     * The resource strings.
    */
    get resourceStrings(): IgrCalendarResourceStrings;
    set resourceStrings(v: IgrCalendarResourceStrings);
    get size(): SizableComponentSize;
    set size(v: SizableComponentSize);
    findByName(name: string): any;
    private _change;
    private _change_wrapped;
    get change(): (s: IgrCalendar, e: IgrComponentDataValueChangedEventArgs) => void;
    set change(ev: (s: IgrCalendar, e: IgrComponentDataValueChangedEventArgs) => void);
}
export interface IIgrCalendarProps extends IIgrCalendarBaseProps {
    value?: Date;
    values?: Date[];
    /**
     * Sets the date which is shown in view and is highlighted. By default it is the current date.
    */
    activeDate?: Date;
    /**
     * Controls the visibility of the dates that do not belong to the current month.
    */
    hideOutsideDays?: boolean | string;
    /**
     * Determines whether the calendar hides its header. Even if set to false, the header is not displayed for `multiple` selection.
    */
    hideHeader?: boolean | string;
    /**
     * The orientation of the header.
    */
    headerOrientation?: CalendarHeaderOrientation | string;
    /**
     * The orientation of the multiple months displayed in days view.
    */
    orientation?: CalendarOrientation | string;
    /**
     * The number of months displayed in days view.
    */
    visibleMonths?: number | string;
    /**
     * The active view.
    */
    activeView?: CalendarActiveView | string;
    /**
     * The options used to format the months and the weekdays in the calendar views.
    */
    formatOptions?: IgrCalendarFormatOptions;
    /**
     * The resource strings.
    */
    resourceStrings?: IgrCalendarResourceStrings;
    size?: SizableComponentSize | string;
    change?: (s: IgrCalendar, e: IgrComponentDataValueChangedEventArgs) => void;
}
