import * as React from 'react';
import { DropdownPlacement } from "./DropdownPlacement";
import { DropdownPositionStrategy } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy } from "./DropdownScrollStrategy";
import { SizableComponentSize } from "./SizableComponentSize";
import { IgrDropdownItemComponentEventArgs } from "./igr-dropdown-item-component-event-args";
import { IgrDropdownItem } from "./igr-dropdown-item";
import { Dropdown } from "./Dropdown";
/**
 * Represents a DropDown component.
*/
export declare class IgrDropdown<P extends IIgrDropdownProps = IIgrDropdownProps> extends React.Component<P, {}> {
    protected createImplementation(): Dropdown;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): Dropdown; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrDropdown;
    private onImplementationCreated;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: P["className"];
        style: P["style"];
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * Whether the dropdown should be kept open on selection.
    */
    get keepOpenOnSelect(): boolean;
    set keepOpenOnSelect(v: boolean);
    /**
     * Sets the open state of the component.
    */
    get open(): boolean;
    set open(v: boolean);
    /**
     * The preferred placement of the component around the target element.
     * @type {"top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "right" | "right-start" | "right-end" | "left" | "left-start" | "left-end"}
    */
    get placement(): DropdownPlacement;
    set placement(v: DropdownPlacement);
    /**
     * Sets the component's positioning strategy.
    */
    get positionStrategy(): DropdownPositionStrategy;
    set positionStrategy(v: DropdownPositionStrategy);
    /**
     * Determines the behavior of the component during scrolling the container.
    */
    get scrollStrategy(): DropdownScrollStrategy;
    set scrollStrategy(v: DropdownScrollStrategy);
    /**
     * Whether the component should be flipped to the opposite side of the target once it's about to overflow the visible area.
     * When true, once enough space is detected on its preferred side, it will flip back.
    */
    get flip(): boolean;
    set flip(v: boolean);
    /**
     * The distance from the target element.
    */
    get distance(): number;
    set distance(v: number);
    /**
     * Whether the component should be kept open on clicking outside of it.
    */
    get keepOpenOnOutsideClick(): boolean;
    set keepOpenOnOutsideClick(v: boolean);
    /**
     * Whether the dropdown's width should be the same as the target's one.
    */
    get sameWidth(): boolean;
    set sameWidth(v: boolean);
    get size(): SizableComponentSize;
    set size(v: SizableComponentSize);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Shows the dropdown.
    
    */
    show(): void;
    /**
     * Toggles the open state of the dropdown.
    
    */
    toggle(): void;
    /**
     * Shows the dropdown.
    
    */
    showTarget(target_: any): void;
    /**
     * Toggles the open state of the dropdown.
    
    */
    toggleTarget(target_: any): void;
    /**
     * Navigates to the item at the specified index. If it exists, returns the found item, otherwise - null.
    
    */
    navigateTo(index: any): IgrDropdownItem;
    /**
     * Selects the item with the specified value. If it exists, returns the found item, otherwise - null.
    
    */
    select(value: any): IgrDropdownItem;
    firstUpdated(): void;
    /**
     * Hides the dropdown.
    
    */
    hide(): void;
    /**
     * Clears the current selection of the dropdown.
    
    */
    clearSelection(): void;
    private _change;
    private _change_wrapped;
    get change(): (s: IgrDropdown, e: IgrDropdownItemComponentEventArgs) => void;
    set change(ev: (s: IgrDropdown, e: IgrDropdownItemComponentEventArgs) => void);
}
export interface IIgrDropdownProps {
    children?: React.ReactNode;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * Whether the dropdown should be kept open on selection.
    */
    keepOpenOnSelect?: boolean | string;
    /**
     * Sets the open state of the component.
    */
    open?: boolean | string;
    /**
     * The preferred placement of the component around the target element.
     * @type {"top" | "top-start" | "top-end" | "bottom" | "bottom-start" | "bottom-end" | "right" | "right-start" | "right-end" | "left" | "left-start" | "left-end"}
    */
    placement?: DropdownPlacement | string;
    /**
     * Sets the component's positioning strategy.
    */
    positionStrategy?: DropdownPositionStrategy | string;
    /**
     * Determines the behavior of the component during scrolling the container.
    */
    scrollStrategy?: DropdownScrollStrategy | string;
    /**
     * Whether the component should be flipped to the opposite side of the target once it's about to overflow the visible area.
     * When true, once enough space is detected on its preferred side, it will flip back.
    */
    flip?: boolean | string;
    /**
     * The distance from the target element.
    */
    distance?: number | string;
    /**
     * Whether the component should be kept open on clicking outside of it.
    */
    keepOpenOnOutsideClick?: boolean | string;
    /**
     * Whether the dropdown's width should be the same as the target's one.
    */
    sameWidth?: boolean | string;
    size?: SizableComponentSize | string;
    change?: (s: IgrDropdown, e: IgrDropdownItemComponentEventArgs) => void;
}
