import * as React from 'react';
import { SizableComponentSize } from "./SizableComponentSize";
import { IgrComponentValueChangedEventArgs } from "./igr-component-value-changed-event-args";
import { IgrVoidEventArgs } from "./igr-void-event-args";
import { IgrThemeController } from "./igr-theme-controller";
import { IgrFocusOptions } from "./igr-focus-options";
import { InputBaseDirection } from "./InputBaseDirection";
import { InputBaseSelectMode } from "./InputBaseSelectMode";
import { InputBase } from "./InputBase";
export declare abstract class IgrInputBase<P extends IIgrInputBaseProps = IIgrInputBaseProps> extends React.Component<P, {}> {
    protected createImplementation(): InputBase;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): InputBase; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrInputBase;
    private onImplementationCreated;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): any;
    /**
     * The name attribute of the control.
    */
    get name(): string;
    set name(v: string);
    get outlined(): boolean;
    set outlined(v: boolean);
    /**
     * Makes the control a required field.
    */
    get required(): boolean;
    set required(v: boolean);
    /**
     * Makes the control a disabled field.
    */
    get disabled(): boolean;
    set disabled(v: boolean);
    /**
     * Makes the control a readonly field.
    */
    get readonly(): boolean;
    set readonly(v: boolean);
    /**
     * The placeholder attribute of the control.
    */
    get placeholder(): string;
    set placeholder(v: string);
    /**
     * The label for the control.
    */
    get label(): string;
    set label(v: string);
    get size(): SizableComponentSize;
    set size(v: SizableComponentSize);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    connectedCallback(): void;
    themeAdopted(controller: IgrThemeController): void;
    /**
     * Sets focus on the control.
    
    */
    focusComponent(options: IgrFocusOptions): void;
    /**
     * Removes focus from the control.
    
    */
    blurComponent(): void;
    setSelectionRange(start: number, end: number, direction: InputBaseDirection): void;
    setRangeText(replacement: string, start: number, end: number, selectMode: InputBaseSelectMode): void;
    private _inputOcurred;
    private _inputOcurred_wrapped;
    get inputOcurred(): (s: IgrInputBase, e: IgrComponentValueChangedEventArgs) => void;
    set inputOcurred(ev: (s: IgrInputBase, e: IgrComponentValueChangedEventArgs) => void);
    private _focus;
    private _focus_wrapped;
    get focus(): (s: IgrInputBase, e: IgrVoidEventArgs) => void;
    set focus(ev: (s: IgrInputBase, e: IgrVoidEventArgs) => void);
    private _blur;
    private _blur_wrapped;
    get blur(): (s: IgrInputBase, e: IgrVoidEventArgs) => void;
    set blur(ev: (s: IgrInputBase, e: IgrVoidEventArgs) => void);
}
export interface IIgrInputBaseProps {
    children?: React.ReactNode;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * The name attribute of the control.
    */
    name?: string;
    outlined?: boolean | string;
    /**
     * Makes the control a required field.
    */
    required?: boolean | string;
    /**
     * Makes the control a disabled field.
    */
    disabled?: boolean | string;
    /**
     * Makes the control a readonly field.
    */
    readonly?: boolean | string;
    /**
     * The placeholder attribute of the control.
    */
    placeholder?: string;
    /**
     * The label for the control.
    */
    label?: string;
    size?: SizableComponentSize | string;
    inputOcurred?: (s: IgrInputBase, e: IgrComponentValueChangedEventArgs) => void;
    focus?: (s: IgrInputBase, e: IgrVoidEventArgs) => void;
    blur?: (s: IgrInputBase, e: IgrVoidEventArgs) => void;
}
