import * as React from 'react';
import { MaskInputDir } from "./MaskInputDir";
import { MaskInputValueMode } from "./MaskInputValueMode";
import { IgrInputBase, IIgrInputBaseProps } from "./igr-input-base";
import { MaskInput } from "./MaskInput";
/**
 * A masked input is an input field where a developer can control user input and format the visible value,
 * based on configurable rules
*/
export declare class IgrMaskInput extends IgrInputBase<IIgrMaskInputProps> {
    protected createImplementation(): MaskInput;
    /**
                                 * @hidden
                                 */
    get i(): MaskInput;
    constructor(props: IIgrMaskInputProps);
    componentDidMount(): void;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: string;
        style: React.CSSProperties;
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * The direction attribute of the control.
    */
    get dir(): MaskInputDir;
    set dir(v: MaskInputDir);
    /**
     * Controls the validity of the control.
    */
    get invalid(): boolean;
    set invalid(v: boolean);
    /**
     * Dictates the behavior when retrieving the value of the control:
     * - `raw` will return the clean user input.
     * - `withFormatting` will return the value with all literals and prompts.
    */
    get valueMode(): MaskInputValueMode;
    set valueMode(v: MaskInputValueMode);
    get value(): string;
    set value(v: string);
    /**
     * The mask pattern to apply on the input.
    */
    get mask(): string;
    set mask(v: string);
    /**
     * The prompt symbol to use for unfilled parts of the mask.
    */
    get prompt(): string;
    set prompt(v: string);
    connectedCallback(): void;
    /**
     * Checks for validity of the control and shows the browser message if it's invalid.
    
    */
    reportValidity(): void;
    /**
     * Sets a custom validation message for the control.
     * As long as `message` is not empty, the control is considered invalid.
    
    */
    setCustomValidity(message: string): void;
    /**
     * Check for validity of the control
    
    */
    checkValidity(): void;
    /**
     * Selects all text within the input.
    
    */
    select(): void;
}
export interface IIgrMaskInputProps extends IIgrInputBaseProps {
    /**
     * The direction attribute of the control.
    */
    dir?: MaskInputDir | string;
    /**
     * Controls the validity of the control.
    */
    invalid?: boolean | string;
    /**
     * Dictates the behavior when retrieving the value of the control:
     * - `raw` will return the clean user input.
     * - `withFormatting` will return the value with all literals and prompts.
    */
    valueMode?: MaskInputValueMode | string;
    value?: string;
    /**
     * The mask pattern to apply on the input.
    */
    mask?: string;
    /**
     * The prompt symbol to use for unfilled parts of the mask.
    */
    prompt?: string;
}
