import * as React from 'react';
import { SizableComponentSize } from "./SizableComponentSize";
import { IgrNumberEventArgs } from "./igr-number-event-args";
import { Rating } from "./Rating";
/**
 * Rating provides insight regarding others' opinions and experiences,
 * and can allow the user to submit a rating of their own
*/
export declare class IgrRating<P extends IIgrRatingProps = IIgrRatingProps> extends React.Component<P, {}> {
    protected createImplementation(): Rating;
    protected _implementation: any;
    /**
     * @hidden
     */
    get i(): Rating; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgrRating;
    private onImplementationCreated;
    constructor(props: P);
    componentDidMount(): void;
    shouldComponentUpdate(nextProps: any, nextState: any): boolean;
    render(): React.DOMElement<{
        ref: (ref: any) => void;
        className: P["className"];
        style: P["style"];
        children: any[];
    }, any>;
    protected _elRef: HTMLElement;
    protected _getMainRef(ref: any): void;
    /**
     * The maximum value for the rating
    */
    get max(): number;
    set max(v: number);
    /**
     * The minimum value change allowed.
    */
    get step(): number;
    set step(v: number);
    /**
     * The symbol which the rating will display.
    */
    get symbol(): string;
    set symbol(v: string);
    /**
     * The name attribute of the control
    */
    get name(): string;
    set name(v: string);
    /**
     * The label of the control.
    */
    get label(): string;
    set label(v: string);
    /**
     * A format string which sets aria-valuetext. All instances of '{0}' will be replaced
     * with the current value of the control.
     * Important for screen-readers and useful for localization.
    */
    get valueFormat(): string;
    set valueFormat(v: string);
    /**
     * The current value of the component
    */
    get value(): number;
    set value(v: number);
    /**
     * Sets the disabled state of the component
    */
    get disabled(): boolean;
    set disabled(v: boolean);
    /**
     * Sets hover preview behavior for the component
    */
    get hoverPreview(): boolean;
    set hoverPreview(v: boolean);
    /**
     * Sets the readonly state of the component
    */
    get readonly(): boolean;
    set readonly(v: boolean);
    get size(): SizableComponentSize;
    set size(v: SizableComponentSize);
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected get hasUserValues(): Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
     * Increments the value of the control by `n` steps multiplied by the
     * step factor.
    
    */
    stepUp(n: number): void;
    /**
     * Decrements the value of the control by `n` steps multiplied by
     * the step factor.
    
    */
    stepDown(n: number): void;
    private _change;
    private _change_wrapped;
    get change(): (s: IgrRating, e: IgrNumberEventArgs) => void;
    set change(ev: (s: IgrRating, e: IgrNumberEventArgs) => void);
    private _hover;
    private _hover_wrapped;
    get hover(): (s: IgrRating, e: IgrNumberEventArgs) => void;
    set hover(ev: (s: IgrRating, e: IgrNumberEventArgs) => void);
}
export interface IIgrRatingProps {
    children?: React.ReactNode;
    className?: string | undefined;
    style?: React.CSSProperties | undefined;
    /**
     * The maximum value for the rating
    */
    max?: number | string;
    /**
     * The minimum value change allowed.
    */
    step?: number | string;
    /**
     * The symbol which the rating will display.
    */
    symbol?: string;
    /**
     * The name attribute of the control
    */
    name?: string;
    /**
     * The label of the control.
    */
    label?: string;
    /**
     * A format string which sets aria-valuetext. All instances of '{0}' will be replaced
     * with the current value of the control.
     * Important for screen-readers and useful for localization.
    */
    valueFormat?: string;
    /**
     * The current value of the component
    */
    value?: number | string;
    /**
     * Sets the disabled state of the component
    */
    disabled?: boolean | string;
    /**
     * Sets hover preview behavior for the component
    */
    hoverPreview?: boolean | string;
    /**
     * Sets the readonly state of the component
    */
    readonly?: boolean | string;
    size?: SizableComponentSize | string;
    change?: (s: IgrRating, e: IgrNumberEventArgs) => void;
    hover?: (s: IgrRating, e: IgrNumberEventArgs) => void;
}
